ClientConfigSource

Trait ClientConfigSource 

pub trait ClientConfigSource {
    // Required method
    fn client_config(&self) -> ClientConfig;
}
A source that can provide a ClientConfig. If you are using this crate in your own application, you can implement this trait on your configuration type so that it can be passed to Client::from_source.

Required Methods

fn client_config(&self) -> ClientConfig

Provides a ClientConfig.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors